<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Attachment;
use Illuminate\Support\Facades\Storage;

class AttachmentController extends Controller
{
    /**
     * Show the form for uploading an attachment.
     */
    public function create()
    {
        // Retrieve the existing attachment if any
        $attachment = Attachment::first();
        return view('attachments.create', compact('attachment'));
    }

    /**
     * Store the uploaded attachment.
     */
    public function store(Request $request)
    {
        // Validate the uploaded file
        $request->validate([
            'attachment' => 'required|file|mimes:pdf,png,jpg,jpeg|max:20480', // Max 20MB
        ]);

        // Get the uploaded file
        $file = $request->file('attachment');
        $fileName = $file->getClientOriginalName();
        $filePath = $file->getRealPath();
        $fileContents = file_get_contents($filePath);
        $base64 = base64_encode($fileContents);

        // Check if an attachment already exists
        $attachment = Attachment::first();

        if ($attachment) {
            // Update existing attachment
            $attachment->update([
                'file_name' => $fileName,
                'base64_content' => $base64,
            ]);
        } else {
            // Create new attachment
            Attachment::create([
                'file_name' => $fileName,
                'base64_content' => $base64,
            ]);
        }

        return redirect()->back()->with('success', 'Attachment uploaded successfully!');
    }
}
