<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Route;
use App\Models\SpreadsheetData;
use App\Models\PlaidAccount;

class PlaidController extends Controller
{
    private $client_id;
    private $secret;
    private $env;

    public function __construct()
    {
        $this->client_id = env('PLAID_CLIENT_ID');
        $this->secret = env('PLAID_SECRET');
        $this->env = env('PLAID_ENV', 'sandbox');
    }


    public function index()
    {
        return view('plaid');
    }
    
      public function form()
    {
        return view('zigaform');
    }

    public function indexRedcapital()
    {
        return view('plaidRedcapital');
    }
    
      public function formRedcapital()
    {
        return view('zigaformRedcapital');
    }
    
    public function verification()
    {
        return view('verify');
    }
    
  
    
    private function makeRequest($url, $data)
    {
        $response = Http::post($url, array_merge($data, [
            'client_id' => $this->client_id,
            'secret' => $this->secret,
        ]));

        return $response->json();
    }

    public function createLinkToken(Request $request)
    {
        $url = "https://{$this->env}.plaid.com/link/token/create";
        $response = $this->makeRequest($url, [
            'user' => ['client_user_id' => uniqid()],
            'client_name' => 'FundBaseCamp',
            'country_codes' => ['US'],
            'language' => 'en',
            'products' => ['auth'],
        ]);

        return response()->json(['link_token' => $response['link_token']]);
    }

public function exchangePublicToken(Request $request)
    {
        $url = "https://{$this->env}.plaid.com/item/public_token/exchange";
        $response = $this->makeRequest($url, [
            'public_token' => $request->input('public_token'),
        ]);

        $accessToken = $response['access_token'];
        $itemId = $response['item_id'];

        $accountsUrl = "https://{$this->env}.plaid.com/accounts/get";
        $accountsResponse = $this->makeRequest($accountsUrl, [
            'access_token' => $accessToken,
        ]);

        foreach ($accountsResponse['accounts'] as $accountData) {
            $account = PlaidAccount::create([
                'access_token' => $accessToken,
                'item_id' => $itemId,
                'user_id' => null,
                'name' => $accountData['name'],
                'type' => $accountData['type'],
                'subtype' => $accountData['subtype'],
            ]);

            $balanceData = $accountData['balances'];
         $account->balances()->create([
            'available' => $balanceData['available'],
            'current' => $balanceData['current'],
            'iso_currency_code' => $balanceData['iso_currency_code'] ?? null,
            'last_updated' => $balanceData['last_updated'] ?? now(), // Default to now() if not provided
        ]);


            Log::info('Account and balance stored', [
                'account' => $account->toArray(),
                'balance' => $balanceData,
            ]);

           $this->sendToZapier([
            'account_name' => $account->name,
            'account_type' => $account->type,
            'account_subtype' => $account->subtype,
            'balance_available' => $balanceData['available'],
            'balance_current' => $balanceData['current'],
            'currency_code' => $balanceData['iso_currency_code'],
            'date' => $balanceData['last_updated'] ?? now()->toDateTimeString(), // Default to current date if missing
        ]);

        }

        return response()->json([
        'status' => 'success',
        'redirect_url' => 'https://fundbasecamp.systems/index.php/?form=15',
    ]);
    }


    protected function sendToZapier(array $data)
    {
        try {
            $zapierWebhookUrl = 'https://hooks.zapier.com/hooks/catch/19520719/2kwrq3q/';
    
            \Illuminate\Support\Facades\Http::post($zapierWebhookUrl, $data);
        } catch (\Exception $e) {
            \Log::error("Error sending data to Zapier: " . $e->getMessage());
        }
    }
    
         public function paymentProcessing()
    {
        return view('paymentprocessing');
    }
    
    
}