<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\SpreadsheetData;
use Illuminate\Support\Facades\Log; // Correct import for Log facade

class SpreadsheetWebhookController extends Controller
{
    public function store(Request $request)
    {
        Log::info('Incoming request from Zapier:', $request->all());

        try {
            $data = $request->validate([
                   'date' => 'required|date',
            'memo' => 'nullable|string',
            'check_number' => 'nullable|string',
            'bank_account' => 'nullable|string',
            'bank_type' => 'nullable|string',
            'bank_subtype' => 'nullable|string',
            'bank_balance' => 'nullable|string',
            'committed_amount' => 'required|numeric',
            'user' => 'nullable|string',
            'payer_name' => 'nullable|string',
            'email' => 'nullable|string',
            'payer_address' => 'nullable|string',
            'payer_signer' => 'nullable|string',
            'payee_name' => 'nullable|string',
            'payee_address' => 'nullable|string',
            'payer_address1' => 'nullable|string',
            'payer_address2' => 'nullable|string',
            'payee_zip' => 'nullable|string',
            'payee_country' => 'nullable|string',
            'signature' => 'nullable|string',
            ]);

            Log::info('Validated data:', $data);

            SpreadsheetData::create($data);

            Log::info('Data saved successfully.');

            return response()->json(['message' => 'Data saved successfully'], 201);
        } catch (\Exception $e) {
            Log::error('Error saving data: ' . $e->getMessage());
            return response()->json(['error' => 'Failed to save data'], 500);
        }
    }
    
    public function voidInvestors(Request $request)
    {
        try {
            $data = $request->all();

            foreach ($data as $row) {
                $bank_balance = $row['bank_balance'];
                $committed_amount = $row['committed_amount'];

                if ($bank_balance < $committed_amount) {
                    // Void the investor
                    SpreadsheetData::where('id', $row['id'])->update([
                        'status' => 'voided',
                        'message' => "We're sorry to inform you but you have insufficient balance to continue with the investment. Hope you understand."
                    ]);
                }
            }

            return response()->json(['message' => 'Investors voided successfully.']);
        } catch (\Exception $e) {
            Log::error("Error voiding investors: " . $e->getMessage());
            return response()->json(['error' => 'Failed to void investors'], 500);
        }
    }
}
