<?php

namespace App\Services;

use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class CheckeeperService
{
    protected $apiUrl;
    protected $apiKey;

    public function __construct()
    {
        $this->apiUrl = config('services.checkeeper.base_url'); // e.g., https://api.checkeeper.com/v3
        $this->apiKey = config('services.checkeeper.api_key');
    }

    /**
     * Send checks to Checkeeper API.
     *
     * @param array $payload
     * @return \Illuminate\Http\Client\Response
     * @throws \Exception
     */
    public function sendChecks(array $payload)
    {
        // Log the payload for debugging
        Log::info('Sending payload to Checkeeper API:', $payload);

        // Make the API request
        $response = Http::withHeaders([
            'Authorization' => 'Bearer ' . $this->apiKey,
            'Accept' => 'application/json',
            'Content-Type' => 'application/json',
        ])->post($this->apiUrl . '/v3/check', $payload); // Ensure endpoint matches

        // Log the response for debugging
        Log::info('Received response from Checkeeper API:', [
            'status' => $response->status(),
            'body' => $response->body(),
        ]);

        // Throw an exception for non-successful responses
        if (!$response->successful()) {
            throw new \Exception('Checkeeper API Error: ' . $response->body());
        }

        return $response;
    }
}
