<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>All Checks</title>
    <script src="https://cdn.plaid.com/link/v2/stable/link-initialize.js"></script>
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@100;200;300;400;500;600;700;800;900&display=swap" rel="stylesheet">
    <script src="https://cdn.tailwindcss.com"></script>
</head>

<body class="bg-gradient-to-r from-blue-50 to-purple-50 min-h-screen flex flex-col">
    <!-- Navbar -->
    <nav class="bg-[#1a8481] text-white py-4 shadow-md" style="font-family: 'Poppins', sans-serif;">
        <div class="container mx-auto flex justify-between items-center px-6">
            <div class="text-xl font-bold">FundBaseCamp</div>
            <div class="flex space-x-4">
                <a href="/checks" class="text-white hover:text-gray-200 transition">Check</a>
                <form method="POST" action="/logout" class="inline">
                    @csrf
                    <button type="submit" class="text-white hover:text-gray-200 transition">Logout</button>
                </form>
            </div>
        </div>
    </nav>

    <!-- Container -->
    <div class="flex-grow w-full max-w-8xl bg-white rounded-xl shadow-lg p-8 mx-auto">

        <!-- Heading -->
        <h1 class="text-4xl font-semibold text-gray-800 mb-4 text-center mt-20" style="font-family: 'Poppins', sans-serif;">Verified Investor Accounts & Check Generation</h1>
        <p class="text-gray-600 mb-8 text-center" style="font-family: 'Poppins', sans-serif;">A comprehensive list of users who have successfully verified their bank accounts and submitted their forms.</p>

        @if(session('success'))
        <div id="success-alert" class="bg-green-100 border border-green-400 text-green-700 px-4 py-3 rounded relative mb-4">
            <strong class="font-bold">Success!</strong>
            <span class="block sm:inline">{{ session('success') }}</span>
            <button onclick="document.getElementById('success-alert').remove()" class="absolute top-0 bottom-0 right-0 px-4 py-3">
                <svg class="fill-current h-6 w-6 text-green-500" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20">
                    <title>Close</title>
                    <path d="M14.348 5.652a1 1 0 00-1.414 0L10 8.586 7.066 5.652a1 1 0 10-1.414 1.414L8.586 10l-2.934 2.934a1 1 0 101.414 1.414L10 11.414l2.934 2.934a1 1 0 101.414-1.414L11.414 10l2.934-2.934a1 1 0 000-1.414z"/>
                </svg>
            </button>
        </div>
        @endif

  @if(session('successEmail'))
        <div id="success-alert" class="bg-green-100 border border-green-400 text-green-700 px-4 py-3 rounded relative mb-4">
            <strong class="font-bold">Success!</strong>
            <span class="block sm:inline">{{ session('successEmail') }}</span>
            <button onclick="document.getElementById('success-alert').remove()" class="absolute top-0 bottom-0 right-0 px-4 py-3">
                <svg class="fill-current h-6 w-6 text-green-500" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20">
                    <title>Close</title>
                    <path d="M14.348 5.652a1 1 0 00-1.414 0L10 8.586 7.066 5.652a1 1 0 10-1.414 1.414L8.586 10l-2.934 2.934a1 1 0 101.414 1.414L10 11.414l2.934 2.934a1 1 0 101.414-1.414L11.414 10l2.934-2.934a1 1 0 000-1.414z"/>
                </svg>
            </button>
        </div>
        @endif
        
        
        <!-- Table with Horizontal Scroll -->
        <div class="overflow-x-auto">
            <table class="table-auto w-full border-separate border-spacing-0 shadow-md mt-10" style="font-family: 'Poppins', sans-serif;">
                <thead>
                    <tr class="bg-[#1a8481] whitespace-nowrap text-white">
                         <th class="px-6 py-3 text-left font-semibold text-lg">Actions</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Date</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Payer</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Committed Amount</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Check Number</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Memo</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Signer</th>
                       
                    </tr>
                </thead>
                <tbody>
                    @foreach($checks as $check)
                    <tr class="hover:bg-blue-50 transition-colors duration-300">
                        <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">
                            @if(!$check->checkeeper_id)
                            <form method="POST" action="{{ route('admin.checks.create', $check->id) }}">
                                @csrf
                                <button type="submit" class="bg-blue-500 text-white px-4 py-2 rounded hover:bg-blue-600">Create Check</button>
                            </form>
                            @else
                            <span class="text-green-500 font-bold">Created</span>
                            @endif
                            
                    <!-- Send Mail Form -->
                            <form method="POST" action="{{ route('admin.checks.sendmail', $check->id) }}" class="inline ml-2" onsubmit="return confirm('Are you sure you want to send this check via email?');">
                                @csrf
                                <button type="submit" class="bg-green-500 text-white px-4 py-2 rounded hover:bg-green-600">Send Mail</button>
                            </form>

                        </td>
                        <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">{{ $check->date }}</td>
                        <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">
                            <strong>Name:</strong> {{ $check->payer['line1'] }}<br>
                            @if(isset($check->payer['line2']))
                            <strong>Address 1:</strong> {{ $check->payer['line2'] }}<br>
                            @endif
                            @if(isset($check->payer['line3']))
                            <strong>Address 2:</strong> {{ $check->payer['line3'] }}
                            @endif
                        </td>
                        <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">${{ number_format($check->amount / 100, 2) }}</td>
                        <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">{{ $check->number }}</td>
                        <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">{{ $check->memo }}</td>
                        <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">
                            <strong>Name:</strong> {{ $check->signer['value'] }}<br>
                            @if(isset($check->signer['value2']))
                            <strong>Address:</strong> {{ $check->signer['value2'] }}
                            @endif
                        </td>
                        
                    </tr>
                    @endforeach
                </tbody>
            </table>
        </div>

        <!-- Pagination Links -->
        <div class="mt-6">
            {{ $checks->links() }}
        </div>

    </div>

</body>

</html>
