<?php

use App\Http\Controllers\ProfileController;
use App\Http\Controllers\PlaidController;
use App\Http\Controllers\CheckController;
use App\Http\Controllers\AttachmentController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Mail;

Route::get('/', function () {
    return view('plaid');
});

Route::get('/test-email', function () {
    try {
        Mail::raw('This is a test email.', function ($message) {
            $message->to('marcousfiles@gmail.com')
                    ->subject('Test Email');
        });
        return 'Email sent successfully!';
    } catch (\Exception $e) {
        return 'Failed to send email: ' . $e->getMessage();
    }
});

Route::get('/paymentprocessing', [PlaidController::class, 'paymentProcessing'])->name('paymentprocessing');
Route::post('/admin/checks/{id}/sendmail', [CheckController::class, 'sendMail'])->name('admin.checks.sendmail');

Route::get('/fundbasecamp/plaid', [PlaidController::class, 'index'])->name('plaid');
Route::get('/fundbasecamp/form', [PlaidController::class, 'form'])->name('form');
Route::get('/redcapital/plaid', [PlaidController::class, 'indexRedcapital'])->name('plaidRedcapital');
Route::get('/redcapital/form', [PlaidController::class, 'formRedcapital'])->name('formRedcapital');
Route::get('/dashboard', function () {
    return view('dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

// Display the upload form
Route::get('/attachments/create', [AttachmentController::class, 'create'])->name('attachments.create');

// Handle the form submission
Route::post('/attachments', [AttachmentController::class, 'store'])->name('attachments.store');

Route::post('/plaid/link-token', [PlaidController::class, 'createLinkToken']);
Route::post('/plaid/exchange-public-token', [PlaidController::class, 'exchangePublicToken']);
Route::get('/plaid/accounts', [PlaidController::class, 'getAccounts']);
Route::get('/plaid/balances', [PlaidController::class, 'getBalances']);

Route::get('/verify', [PlaidController::class, 'verification'])->name('verify');

Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
    Route::get('/accounts', [PlaidController::class, 'showAccounts']);
    // Display all checks
    Route::get('/checks', [CheckController::class, 'index'])->name('admin.checks.index');
    
    // Create check via POST (AJAX)
    Route::post('/checks/{id}/create', [CheckController::class, 'createCheck'])->name('admin.checks.create');

Route::post('checks/sendmail/{id}', [CheckController::class, 'sendMail'])->name('admin.checks.sendmail');
});

require __DIR__.'/auth.php';
