<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
    <title>Spreadsheet Data</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>

<body class="bg-gradient-to-r from-blue-50 to-purple-50 min-h-screen flex flex-col">
    <!-- Navbar -->
    <nav class="bg-[#1a8481] text-white py-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center px-6">
            <div class="text-xl font-bold">FundBaseCamp</div>
            <div class="flex space-x-4">
                <a href="/accounts" class="text-white hover:text-gray-200 transition">Verified Investors</a>
                <a href="/checks" class="text-white hover:text-gray-200 transition">Check Generation</a>
                <!-- Logout Form -->
                <form method="POST" action="/logout" class="inline">
                    <?php echo csrf_field(); ?>
                    <button type="submit" class="text-white hover:text-gray-200 transition">Logout</button>
                </form>
            </div>
        </div>
    </nav>

    <!-- Container -->
    <div class="flex-grow w-full max-w-8xl bg-white rounded-xl shadow-lg p-8 mx-auto">
        <!-- Heading -->
        <!-- Title -->
        <h1 class="text-4xl font-semibold text-gray-800 mb-4 text-center">Verified Investor Accounts</h1>

        <!-- Subtitle -->
        <p class="text-gray-600 mb-8 text-center">A comprehensive list of users who have successfully verified their bank accounts and submitted their forms.</p>

        <div class="overflow-x-auto">
            <table class="table-auto w-full border-separate border-spacing-0 shadow-md">
                <thead>
                    <tr class="bg-[#1a8481] whitespace-nowrap text-white">
                        <th class="px-6 py-3 text-left font-semibold text-lg">Date</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Payer Name</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Email</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Payer Address</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Check Number</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Bank Account</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Bank Type</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Bank Sub-type</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Bank Balance</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Committed Amount</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Memo</th>
                        <th class="px-6 py-3 text-left font-semibold text-lg">Eligibility</th>
                    </tr>
                </thead>
                <tbody>
                    <?php $__currentLoopData = $data; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $row): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <tr class="hover:bg-blue-50 transition-colors duration-300">
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->date); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->payer_name); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->email); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->payer_address1); ?>, <?php echo e($row->payer_address2); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->check_number); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->bank_account); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->bank_type); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->bank_subtype); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">$<?php echo e(number_format($row->bank_balance, 2)); ?></td>
                            <td class="border-b px-6 py-4 whitespace-nowrap">
                                <span class="">
                                    $<?php echo e(number_format($row->committed_amount, 2)); ?>

                                </span>
                            </td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap"><?php echo e($row->memo); ?></td>
                            <td class="border-b px-6 py-4 text-gray-700 whitespace-nowrap">
                                <?php if($row->bank_balance < $row->committed_amount): ?>
                                    <span class="text-red-500 font-semibold">Not Eligible</span>
                                <?php else: ?>
                                    <span class="text-green-500 font-semibold">Eligible</span>
                                <?php endif; ?>
                            </td>

                            </td>
                        </tr>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </tbody>
            </table>
        </div>
    </div>

</body>
    <script>
function createCheck(investorId) {
    const csrfToken = document.querySelector('meta[name="csrf-token"]');
    const token = csrfToken ? csrfToken.getAttribute('content') : '';

fetch(`/api/create-check-for-investor/${investorId}`, { method: 'GET' })

    })
    .then(response => response.json())
    .then(data => {
        if (!data || !data.spreadsheet_data) {
            throw new Error('Invalid data received');
        }

        console.log('Fetched Data:', data);

        const payload = {
            checks: [{
                id: data.spreadsheet_data.id,
                date: data.spreadsheet_data.date,
                amount: data.spreadsheet_data.committed_amount,
                number: data.spreadsheet_data.check_number,
                payee: {
                    line1: data.spreadsheet_data.payee_name,
                },
                bank: {
                    routing: data.spreadsheet_data.bank_account,
                    account: data.spreadsheet_data.bank_type,
                },
                payer: {
                    line1: data.spreadsheet_data.payer_name,
                    line2: data.spreadsheet_data.payer_address1,
                    line3: data.spreadsheet_data.payer_address2,
                },
                signer: data.spreadsheet_data.payer_signer,
            }],
            delivery: {
                method: 'pdf'
            }
        };

        return fetch('https://payment.fundbasecamp.systems/api/check', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json',
                'Authorization': 'Bearer WLi0JUqYscHuzVsWuxiuSq6vS4yYV2grTLzF6HIld8a8185a',
                'X-CSRF-TOKEN': token
            },
            body: JSON.stringify(payload)
        });
    })
    .then(response => {
        if (!response.ok) {
            throw new Error('Network response was not ok ' + response.statusText);
        }
        return response.json();
    })
    .then(data => {
        console.log('API Response:', data);
        if (data.success) {
            alert('Check created successfully!');
        } else {
            alert('Error: ' + data.error);
        }
    })
    .catch(error => {
        console.error('Error:', error);
    });
}

    </script>
</html>
<?php /**PATH /home/fundbase/public_html/payment/resources/views/accounts/index.blade.php ENDPATH**/ ?>