<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Connect your Bank Account</title>
    <script src="https://cdn.plaid.com/link/v2/stable/link-initialize.js"></script>
    <?php echo app('Illuminate\Foundation\Vite')('resources/css/app.css'); ?> <!-- Tailwind -->
</head>

<body class="bg-gradient-to-r from-blue-50 via-white to-blue-50 min-h-screen flex items-center justify-center">

    <!-- Main Container -->
    <div class="bg-white shadow-2xl rounded-lg p-8 max-w-lg w-full">
        <h1 class="text-3xl font-semibold text-gray-800 text-center mb-6">Connect Your Bank Account</h1>
        <p class="text-lg text-gray-600 text-center mb-8">
            Securely connect your bank account to manage your finances with ease and confidence.
        </p>

        <!-- Action Buttons -->
        <div class="flex justify-center space-x-6 mb-6">
            <!-- Connect Bank Button -->
            <button id="link-button"
                class="bg-blue-600 hover:bg-blue-700 text-white font-semibold py-3 px-8 rounded-xl shadow-md transform transition duration-300 hover:scale-105 focus:outline-none focus:ring-2 focus:ring-blue-400 focus:ring-opacity-50">
                Connect Bank
            </button>

            <!-- Redirect Button -->
            <button onclick="window.location.href='https://fundbasecamp.systems/'"
                class="bg-green-600 hover:bg-green-700 text-white font-semibold py-3 px-8 rounded-xl shadow-md transform transition duration-300 hover:scale-105 focus:outline-none focus:ring-2 focus:ring-green-400 focus:ring-opacity-50">
                Go to Fund Basecamp
            </button>
        </div>

        <!-- Terms and Privacy Links -->
        <div class="text-center text-sm text-gray-500">
            By connecting your account, you agree to our <a href="#" class="text-blue-600 hover:underline">Terms of
                Service</a> and <a href="#" class="text-blue-600 hover:underline">Privacy Policy</a>.
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', async () => {
            try {
                // Fetch the link token from the server
                const response = await fetch('/plaid/link-token');
                const data = await response.json();

                if (!data.link_token) {
                    throw new Error('Link token could not be retrieved');
                }

                // Initialize Plaid Link
                const handler = Plaid.create({
                    token: data.link_token,
                    onSuccess: (public_token, metadata) => {
                        console.log('Public Token:', public_token);
                        console.log('Metadata:', metadata);

                        // Send the public_token to your server for exchange
                        fetch('/plaid/exchange-token', {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/json',
                                'X-CSRF-TOKEN': '<?php echo e(csrf_token()); ?>',
                            },
                            body: JSON.stringify({ public_token }),
                        })
                            .then(response => response.json())
                            .then(data => {
                                alert('Account linked successfully!');
                                console.log(data);
                            })
                            .catch(error => console.error('Error:', error));
                    },
                    onExit: (err, metadata) => {
                        console.log('User exited:', metadata);
                    },
                });

                // Attach to button
                document.getElementById('link-button').addEventListener('click', () => {
                    handler.open();
                });
            } catch (error) {
                console.error('Error initializing Plaid:', error);
            }
        });
    </script>
</body>

</html>
<?php /**PATH C:\laragon\www\testing-api\resources\views/plaid.blade.php ENDPATH**/ ?>